@@ -8,7 +8,7 @@
 #
 # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # #
 #
-# Copyright (c) 2008 Kenneth J. Pronovici.
+# Copyright (c) 2008,2010 Kenneth J. Pronovici.
 # All rights reserved.
 #
 # This program is free software; you can redistribute it and/or
@@ -25,9 +25,9 @@
 # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # #
 #
 # Author   : Kenneth J. Pronovici <pronovic@ieee.org>
-# Language : Python (>= 2.3)
+# Language : Python (>= 2.5)
 # Project  : Cedar Backup, release 2
-# Revision : $Id: capacity.py 871 2008-03-19 01:27:24Z pronovic $
+# Revision : $Id: capacity.py 1006 2010-07-07 21:03:57Z pronovic $
 # Purpose  : Provides an extension to check remaining media capacity.
 #
 # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # #
@@ -82,8 +82,8 @@ class PercentageQuantity(object):
    precision can be avoided.  It really isn't possible to store a floating
    point number here while being able to losslessly translate back and forth
    between XML and object representations.  (Perhaps the Python 2.4 Decimal
-   class would have been an option, but I want to stay compatible with Python
-   2.3.)
+   class would have been an option, but I originally wanted to stay compatible
+   with Python 2.3.)
 
    Even though the quantity is maintained as a string, the string must be in a
    valid floating point positive number.  Technically, any floating point
@@ -123,8 +123,8 @@ class PercentageQuantity(object):
       """
       if other is None:
          return 1
-      if self._quantity != other._quantity:
-         if self._quantity < other._quantity:
+      if self.quantity != other.quantity:
+         if self.quantity < other.quantity:
             return -1
          else:
             return 1
@@ -214,13 +214,13 @@ class CapacityConfig(object):
       """
       if other is None:
          return 1
-      if self._maxPercentage != other._maxPercentage:
-         if self._maxPercentage < other._maxPercentage:
+      if self.maxPercentage != other.maxPercentage:
+         if self.maxPercentage < other.maxPercentage:
             return -1
          else:
             return 1
-      if self._minBytes != other._minBytes:
-         if self._minBytes < other._minBytes:
+      if self.minBytes != other.minBytes:
+         if self.minBytes < other.minBytes:
             return -1
          else:
             return 1
@@ -358,8 +358,8 @@ class LocalConfig(object):
       """
       if other is None:
          return 1
-      if self._capacity != other._capacity:
-         if self._capacity < other._capacity:
+      if self.capacity != other.capacity:
+         if self.capacity < other.capacity:
             return -1
          else:
             return 1
@@ -435,6 +435,7 @@ class LocalConfig(object):
       (xmlDom, parentNode) = createInputDom(xmlData)
       self._capacity = LocalConfig._parseCapacity(parentNode)
 
+   @staticmethod
    def _parseCapacity(parentNode):
       """
       Parses a capacity configuration section.
@@ -456,8 +457,8 @@ class LocalConfig(object):
          capacity.maxPercentage = LocalConfig._readPercentageQuantity(section, "max_percentage")
          capacity.minBytes = readByteQuantity(section, "min_bytes")
       return capacity
-   _parseCapacity = staticmethod(_parseCapacity)
 
+   @staticmethod
    def _readPercentageQuantity(parent, name):
       """
       Read a percentage quantity value from an XML document.
@@ -469,8 +470,8 @@ class LocalConfig(object):
       if quantity is None:
          return None
       return PercentageQuantity(quantity)
-   _readPercentageQuantity = staticmethod(_readPercentageQuantity)
 
+   @staticmethod
    def _addPercentageQuantity(xmlDom, parentNode, nodeName, percentageQuantity):
       """
       Adds a text node as the next child of a parent, to contain a percentage quantity.
@@ -486,7 +487,6 @@ class LocalConfig(object):
       """
       if percentageQuantity is not None:
          addStringNode(xmlDom, parentNode, nodeName, percentageQuantity.quantity)
-   _addPercentageQuantity = staticmethod(_addPercentageQuantity)
 
 
 ########################################################################
