@@ -27,7 +27,7 @@
 # Author   : Kenneth J. Pronovici <pronovic@ieee.org>
 # Language : Python (>= 2.5)
 # Project  : Official Cedar Backup Extensions
-# Revision : $Id: split.py 1006 2010-07-07 21:03:57Z pronovic $
+# Revision : $Id: split.py 1023 2011-10-11 23:44:50Z pronovic $
 # Purpose  : Provides an extension to split up large files in staging directories.
 #
 # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # #
@@ -475,7 +475,7 @@ def _splitFile(sourcePath, splitSize, backupUser, backupGroup, removeSource=Fals
       dirname = os.path.dirname(sourcePath)
       filename = os.path.basename(sourcePath)
       prefix = "%s_" % filename
-      bytes = int(splitSize.bytes)
+      bytes = int(splitSize.bytes) # pylint: disable=W0622
       os.chdir(dirname) # need to operate from directory that we want files written to
       command = resolveCommand(SPLIT_COMMAND)
       args = [ "--verbose", "--numeric-suffixes", "--suffix-length=5", "--bytes=%d" % bytes, filename, prefix, ]
